==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/sr-CS/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potvrda grupnog brisanja imovine',
    'bulk_restore'      => 'Potvrda grupnog vraćanja imovine', 
  'bulk_delete_help'	=> 'Pregledajte stavke za grupno brisanje. Jednom izbrisana, ta se sredstva mogu vratiti, ali više neće biti povezana s korisnicima koji su trenutno dodeljeni.',
  'bulk_restore_help'	=> 'Pregledajte imovinu ispod za grupno vraćanje. Kada se vrati, ova imovina neće biti zadužena ni jednom korisniku kod kojeg je prethodno bila zadužena.',
  'bulk_delete_warn'	=> 'Izbrisaćete: asset_count assets.',
  'bulk_restore_warn'	=> 'Spremate se da vratite :asset_count imovine.',
    'bulk_update'		=> 'Grupno ažuriranje imovine',
    'bulk_update_help'	=> 'Ova forma vam omogućava da ažururate više stavki odjednom. Popunite samo polja koja želite da izmenite. Nepopunjena polja ostaće nepromenjena. ',
    'bulk_update_warn'	=> 'Sada ćete izmeniti svojstva jedne imovine.|Sada ćete izmeniti svojstva :asset_count imovina.',
    'bulk_update_with_custom_field' => 'Primetite da su imovine :asset_model_count različite vrste modela.',
    'bulk_update_model_prefix' => 'Na modelima', 
    'bulk_update_custom_field_unique' => 'Ovo je jedinstveno polje koje se ne može grupno menjati.',
    'checkedout_to'		=> 'Checked Out To',
    'checkout_date'		=> 'Checkout Date',
    'checkin_date'		=> 'Checkin Date',
    'checkout_to'		=> 'Checkout to',
    'cost'				=> 'Cena nabavke',
    'create'			=> 'Kreiraj resurs',
    'date'				=> 'Datum kupovine',
    'depreciation'	    => 'Amortizacija',
    'depreciates_on'	=> 'Depreciates On',
    'default_location'	=> 'Podrazumevana lokacija',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'EOL stopa',
    'expected_checkin'  => 'Očekivani datum provere',
    'expires'			=> 'Ističe',
    'fully_depreciated'	=> 'Potpuno amortizovano',
    'help_checkout'		=> 'Ako želite odmah dodijeliti ovaj resurs, odaberite "Spreman za korošćenje" iz gornje liste statusa. ',
    'mac_address'		=> 'MAC Adresa',
    'manufacturer'		=> 'Proizvođač',
    'model'				=> 'Model',
    'months'			=> 'meseci',
    'name'				=> 'Naziv imovine',
    'notes'				=> 'Zabeleške',
    'order'				=> 'Broj narudžbine',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Korisnici mogu zatražiti ovaj resurs',
    'select_statustype'	=> 'Odaberite vrstu statusa',
    'serial'			=> 'Serial',
    'status'			=> 'Status',
    'tag'				=> 'Oznaka imovine',
    'update'			=> 'Ažuriranje imovine',
    'warranty'			=> 'Garancija',
        'warranty_expires'		=> 'Garancija ističe',
    'years'				=> 'godina',
    'asset_location' => 'Izmeni lokaciju imovine',
    'asset_location_update_default_current' => 'Izmeni predefinisanu i stvarnu lokaciju',
    'asset_location_update_default' => 'Izmeni samo predefinisanu lokaciju',
    'asset_location_update_actual' => 'Izmeni samo stvarnu lokaciju',
    'asset_not_deployable' => 'Status imovine je nezaduživo. Ova imovina se ne može zadužiti.',
    'asset_deployable' => 'Status imovine je zaduživo. Ova imovina se može zadužiti.',
    'processing_spinner' => 'Obrađivanje... (Ovo bi moglo da potraje u slučaju velikih datoteka)',
    'optional_infos'  => 'Opcione informacije',
    'order_details'   => 'Informacije o nabavci'
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/sr-CS/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Potvrda grupnog brisanja imovine',
    'bulk_restore'      => 'Potvrda grupnog vraćanja imovine', 
  'bulk_delete_help'	=> 'Pregledajte stavke za grupno brisanje. Jednom izbrisana, ta se sredstva mogu vratiti, ali više neće biti povezana s korisnicima koji su trenutno dodeljeni.',
  'bulk_restore_help'	=> 'Pregledajte imovinu ispod za grupno vraćanje. Kada se vrati, ova imovina neće biti zadužena ni jednom korisniku kod kojeg je prethodno bila zadužena.',
  'bulk_delete_warn'	=> 'Izbrisaćete: asset_count assets.',
  'bulk_restore_warn'	=> 'Spremate se da vratite :asset_count imovine.',
    'bulk_update'		=> 'Grupno ažuriranje imovine',
    'bulk_update_help'	=> 'Ova forma vam omogućava da ažururate više stavki odjednom. Popunite samo polja koja želite da izmenite. Nepopunjena polja ostaće nepromenjena. ',
    'bulk_update_warn'	=> 'Sada ćete izmeniti svojstva jedne imovine.|Sada ćete izmeniti svojstva :asset_count imovina.',
    'bulk_update_with_custom_field' => 'Primetite da su imovine :asset_model_count različite vrste modela.',
    'bulk_update_model_prefix' => 'Na modelima', 
    'bulk_update_custom_field_unique' => 'Ovo je jedinstveno polje koje se ne može grupno menjati.',
    'checkedout_to'		=> 'Checked Out To',
    'checkout_date'		=> 'Checkout Date',
    'checkin_date'		=> 'Checkin Date',
    'checkout_to'		=> 'Checkout to',
    'cost'				=> 'Cena nabavke',
    'create'			=> 'Kreiraj resurs',
    'date'				=> 'Datum kupovine',
    'depreciation'	    => 'Amortizacija',
    'depreciates_on'	=> 'Depreciates On',
    'default_location'	=> 'Podrazumevana lokacija',
    'default_location_phone' => 'Telefon podrazumevane lokacije',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'EOL stopa',
    'expected_checkin'  => 'Očekivani datum provere',
    'expires'			=> 'Ističe',
    'fully_depreciated'	=> 'Potpuno amortizovano',
    'help_checkout'		=> 'Ako želite odmah dodijeliti ovaj resurs, odaberite "Spreman za korošćenje" iz gornje liste statusa. ',
    'mac_address'		=> 'MAC Adresa',
    'manufacturer'		=> 'Proizvođač',
    'model'				=> 'Model',
    'months'			=> 'meseci',
    'name'				=> 'Naziv imovine',
    'notes'				=> 'Zabeleške',
    'order'				=> 'Broj narudžbine',
    'qr'				=> 'QR Code',
    'requestable'		=> 'Korisnici mogu zatražiti ovaj resurs',
    'redirect_to_all'   => 'Vrati se na sve :type',
    'redirect_to_type'   => 'Idi na :type',
    'redirect_to_checked_out_to'   => 'Idi na zaduženo',
    'select_statustype'	=> 'Odaberite vrstu statusa',
    'serial'			=> 'Serial',
    'status'			=> 'Status',
    'tag'				=> 'Oznaka imovine',
    'update'			=> 'Ažuriranje imovine',
    'warranty'			=> 'Garancija',
        'warranty_expires'		=> 'Garancija ističe',
    'years'				=> 'godina',
    'asset_location' => 'Izmeni lokaciju imovine',
    'asset_location_update_default_current' => 'Izmeni predefinisanu i stvarnu lokaciju',
    'asset_location_update_default' => 'Izmeni samo predefinisanu lokaciju',
    'asset_location_update_actual' => 'Izmeni samo stvarnu lokaciju',
    'asset_not_deployable' => 'Status imovine je nezaduživo. Ova imovina se ne može zadužiti.',
    'asset_deployable' => 'Status imovine je zaduživo. Ova imovina se može zadužiti.',
    'processing_spinner' => 'Obrađivanje... (Ovo bi moglo da potraje u slučaju velikih datoteka)',
    'optional_infos'  => 'Opcione informacije',
    'order_details'   => 'Informacije o nabavci'
];
